@@ -279,7 +279,7 @@ CertificateTypeDef = TypedDict(
         "CertificateIdentifier": str,
         "CertificateCreationDate": datetime,
         "CertificatePem": str,
-        "CertificateWallet": StreamingBody,
+        "CertificateWallet": bytes,
         "CertificateArn": str,
         "CertificateOwner": str,
         "ValidFromDate": datetime,
